==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/ClusterOperatorHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterOperatorOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.ClusterOperator;
import io.fabric8.openshift.api.model.ClusterOperatorBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterOperatorHandler implements ResourceHandler<ClusterOperator, ClusterOperatorBuilder> {

  @Override
  public String getKind() {
    return ClusterOperator.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public ClusterOperator create(OkHttpClient client, Config config, String namespace, ClusterOperator item) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ClusterOperator replace(OkHttpClient client, Config config, String namespace, ClusterOperator item) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ClusterOperator reload(OkHttpClient client, Config config, String namespace, ClusterOperator item) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterOperatorBuilder edit(ClusterOperator item) {
    return new ClusterOperatorBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, ClusterOperator item) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, Watcher<ClusterOperator> watcher) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, String resourceVersion, Watcher<ClusterOperator> watcher) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, ListOptions options, Watcher<ClusterOperator> watcher) {
  return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterOperator waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterOperator item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterOperator waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterOperator item, Predicate<ClusterOperator> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.1-sources.jar: io/fabric8/openshift/client/handlers/ClusterOperatorHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterOperatorOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.ClusterOperator;
import io.fabric8.openshift.api.model.ClusterOperatorBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterOperatorHandler implements ResourceHandler<ClusterOperator, ClusterOperatorBuilder> {

  @Override
  public String getKind() {
    return ClusterOperator.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public ClusterOperator create(OkHttpClient client, Config config, String namespace, ClusterOperator item, boolean dryRun) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public ClusterOperator replace(OkHttpClient client, Config config, String namespace, ClusterOperator item, boolean dryRun) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public ClusterOperator reload(OkHttpClient client, Config config, String namespace, ClusterOperator item) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterOperatorBuilder edit(ClusterOperator item) {
    return new ClusterOperatorBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, ClusterOperator item, boolean dryRun) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, Watcher<ClusterOperator> watcher) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, String resourceVersion, Watcher<ClusterOperator> watcher) {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterOperator item, ListOptions options, Watcher<ClusterOperator> watcher) {
  return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterOperator waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterOperator item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterOperator waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterOperator item, Predicate<ClusterOperator> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterOperatorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
